/* Branch.c generated by valac 0.32.1, the Vala compiler
 * generated from Branch.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <gee.h>


#define SIDEBAR_TYPE_BRANCH (sidebar_branch_get_type ())
#define SIDEBAR_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranch))
#define SIDEBAR_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))
#define SIDEBAR_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))

typedef struct _SidebarBranch SidebarBranch;
typedef struct _SidebarBranchClass SidebarBranchClass;
typedef struct _SidebarBranchPrivate SidebarBranchPrivate;

#define LIBRARY_TYPE_BRANCH (library_branch_get_type ())
#define LIBRARY_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_BRANCH, LibraryBranch))
#define LIBRARY_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_BRANCH, LibraryBranchClass))
#define LIBRARY_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_BRANCH))
#define LIBRARY_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_BRANCH))
#define LIBRARY_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_BRANCH, LibraryBranchClass))

typedef struct _LibraryBranch LibraryBranch;
typedef struct _LibraryBranchClass LibraryBranchClass;
typedef struct _LibraryBranchPrivate LibraryBranchPrivate;

#define SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY (sidebar_simple_page_entry_get_type ())
#define SIDEBAR_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))

typedef struct _SidebarSimplePageEntry SidebarSimplePageEntry;
typedef struct _SidebarSimplePageEntryClass SidebarSimplePageEntryClass;

#define LIBRARY_TYPE_PHOTOS_ENTRY (library_photos_entry_get_type ())
#define LIBRARY_PHOTOS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntry))
#define LIBRARY_PHOTOS_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntryClass))
#define LIBRARY_IS_PHOTOS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_PHOTOS_ENTRY))
#define LIBRARY_IS_PHOTOS_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_PHOTOS_ENTRY))
#define LIBRARY_PHOTOS_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntryClass))

typedef struct _LibraryPhotosEntry LibraryPhotosEntry;
typedef struct _LibraryPhotosEntryClass LibraryPhotosEntryClass;

#define LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY (library_hideable_page_entry_get_type ())
#define LIBRARY_HIDEABLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry))
#define LIBRARY_HIDEABLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntryClass))
#define LIBRARY_IS_HIDEABLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY))
#define LIBRARY_IS_HIDEABLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY))
#define LIBRARY_HIDEABLE_PAGE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntryClass))

typedef struct _LibraryHideablePageEntry LibraryHideablePageEntry;
typedef struct _LibraryHideablePageEntryClass LibraryHideablePageEntryClass;

#define LIBRARY_TYPE_FLAGGED_SIDEBAR_ENTRY (library_flagged_sidebar_entry_get_type ())
#define LIBRARY_FLAGGED_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_FLAGGED_SIDEBAR_ENTRY, LibraryFlaggedSidebarEntry))
#define LIBRARY_FLAGGED_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_FLAGGED_SIDEBAR_ENTRY, LibraryFlaggedSidebarEntryClass))
#define LIBRARY_IS_FLAGGED_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_FLAGGED_SIDEBAR_ENTRY))
#define LIBRARY_IS_FLAGGED_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_FLAGGED_SIDEBAR_ENTRY))
#define LIBRARY_FLAGGED_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_FLAGGED_SIDEBAR_ENTRY, LibraryFlaggedSidebarEntryClass))

typedef struct _LibraryFlaggedSidebarEntry LibraryFlaggedSidebarEntry;
typedef struct _LibraryFlaggedSidebarEntryClass LibraryFlaggedSidebarEntryClass;

#define LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY (library_last_import_sidebar_entry_get_type ())
#define LIBRARY_LAST_IMPORT_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY, LibraryLastImportSidebarEntry))
#define LIBRARY_LAST_IMPORT_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY, LibraryLastImportSidebarEntryClass))
#define LIBRARY_IS_LAST_IMPORT_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY))
#define LIBRARY_IS_LAST_IMPORT_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY))
#define LIBRARY_LAST_IMPORT_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY, LibraryLastImportSidebarEntryClass))

typedef struct _LibraryLastImportSidebarEntry LibraryLastImportSidebarEntry;
typedef struct _LibraryLastImportSidebarEntryClass LibraryLastImportSidebarEntryClass;

#define LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY (library_import_queue_sidebar_entry_get_type ())
#define LIBRARY_IMPORT_QUEUE_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY, LibraryImportQueueSidebarEntry))
#define LIBRARY_IMPORT_QUEUE_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY, LibraryImportQueueSidebarEntryClass))
#define LIBRARY_IS_IMPORT_QUEUE_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY))
#define LIBRARY_IS_IMPORT_QUEUE_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY))
#define LIBRARY_IMPORT_QUEUE_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY, LibraryImportQueueSidebarEntryClass))

typedef struct _LibraryImportQueueSidebarEntry LibraryImportQueueSidebarEntry;
typedef struct _LibraryImportQueueSidebarEntryClass LibraryImportQueueSidebarEntryClass;

#define LIBRARY_TYPE_OFFLINE_SIDEBAR_ENTRY (library_offline_sidebar_entry_get_type ())
#define LIBRARY_OFFLINE_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_OFFLINE_SIDEBAR_ENTRY, LibraryOfflineSidebarEntry))
#define LIBRARY_OFFLINE_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_OFFLINE_SIDEBAR_ENTRY, LibraryOfflineSidebarEntryClass))
#define LIBRARY_IS_OFFLINE_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_OFFLINE_SIDEBAR_ENTRY))
#define LIBRARY_IS_OFFLINE_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_OFFLINE_SIDEBAR_ENTRY))
#define LIBRARY_OFFLINE_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_OFFLINE_SIDEBAR_ENTRY, LibraryOfflineSidebarEntryClass))

typedef struct _LibraryOfflineSidebarEntry LibraryOfflineSidebarEntry;
typedef struct _LibraryOfflineSidebarEntryClass LibraryOfflineSidebarEntryClass;

#define LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY (library_trash_sidebar_entry_get_type ())
#define LIBRARY_TRASH_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntry))
#define LIBRARY_TRASH_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntryClass))
#define LIBRARY_IS_TRASH_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY))
#define LIBRARY_IS_TRASH_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY))
#define LIBRARY_TRASH_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntryClass))

typedef struct _LibraryTrashSidebarEntry LibraryTrashSidebarEntry;
typedef struct _LibraryTrashSidebarEntryClass LibraryTrashSidebarEntryClass;

#define LIBRARY_BRANCH_TYPE_ENTRY_POSITION (library_branch_entry_position_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SIDEBAR_TYPE_GROUPING (sidebar_grouping_get_type ())
#define SIDEBAR_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_GROUPING, SidebarGrouping))
#define SIDEBAR_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))
#define SIDEBAR_IS_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_IS_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_GROUPING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))

typedef struct _SidebarGrouping SidebarGrouping;
typedef struct _SidebarGroupingClass SidebarGroupingClass;

#define SIDEBAR_TYPE_HEADER (sidebar_header_get_type ())
#define SIDEBAR_HEADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_HEADER, SidebarHeader))
#define SIDEBAR_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))
#define SIDEBAR_IS_HEADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_IS_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_HEADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))

typedef struct _SidebarHeader SidebarHeader;
typedef struct _SidebarHeaderClass SidebarHeaderClass;

#define SIDEBAR_TYPE_ENTRY (sidebar_entry_get_type ())
#define SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntry))
#define SIDEBAR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ENTRY))
#define SIDEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntryIface))

typedef struct _SidebarEntry SidebarEntry;
typedef struct _SidebarEntryIface SidebarEntryIface;

#define SIDEBAR_TYPE_TREE (sidebar_tree_get_type ())
#define SIDEBAR_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_TREE, SidebarTree))
#define SIDEBAR_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_TREE, SidebarTreeClass))
#define SIDEBAR_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_TREE))
#define SIDEBAR_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_TREE))
#define SIDEBAR_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_TREE, SidebarTreeClass))

typedef struct _SidebarTree SidebarTree;
typedef struct _SidebarTreeClass SidebarTreeClass;

#define SIDEBAR_BRANCH_TYPE_OPTIONS (sidebar_branch_options_get_type ())

#define SIDEBAR_TYPE_SELECTABLE_ENTRY (sidebar_selectable_entry_get_type ())
#define SIDEBAR_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntry))
#define SIDEBAR_IS_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY))
#define SIDEBAR_SELECTABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntryIface))

typedef struct _SidebarSelectableEntry SidebarSelectableEntry;
typedef struct _SidebarSelectableEntryIface SidebarSelectableEntryIface;

#define SIDEBAR_TYPE_PAGE_REPRESENTATIVE (sidebar_page_representative_get_type ())
#define SIDEBAR_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative))
#define SIDEBAR_IS_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE))
#define SIDEBAR_PAGE_REPRESENTATIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentativeIface))

typedef struct _SidebarPageRepresentative SidebarPageRepresentative;
typedef struct _SidebarPageRepresentativeIface SidebarPageRepresentativeIface;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define SIDEBAR_TYPE_CONTEXTABLE (sidebar_contextable_get_type ())
#define SIDEBAR_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextable))
#define SIDEBAR_IS_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_CONTEXTABLE))
#define SIDEBAR_CONTEXTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextableIface))

typedef struct _SidebarContextable SidebarContextable;
typedef struct _SidebarContextableIface SidebarContextableIface;
typedef struct _SidebarSimplePageEntryPrivate SidebarSimplePageEntryPrivate;
typedef struct _LibraryPhotosEntryPrivate LibraryPhotosEntryPrivate;

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;

#define TYPE_MEDIA_PAGE (media_page_get_type ())
#define MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_PAGE, MediaPage))
#define MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_PAGE, MediaPageClass))
#define IS_MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_PAGE))
#define IS_MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_PAGE))
#define MEDIA_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_PAGE, MediaPageClass))

typedef struct _MediaPage MediaPage;
typedef struct _MediaPageClass MediaPageClass;

#define TYPE_COLLECTION_PAGE (collection_page_get_type ())
#define COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_PAGE, CollectionPage))
#define COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_PAGE, CollectionPageClass))
#define IS_COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_PAGE))
#define IS_COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_PAGE))
#define COLLECTION_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_PAGE, CollectionPageClass))

typedef struct _CollectionPage CollectionPage;
typedef struct _CollectionPageClass CollectionPageClass;

#define LIBRARY_TYPE_MAIN_PAGE (library_main_page_get_type ())
#define LIBRARY_MAIN_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_MAIN_PAGE, LibraryMainPage))
#define LIBRARY_MAIN_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_MAIN_PAGE, LibraryMainPageClass))
#define LIBRARY_IS_MAIN_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_MAIN_PAGE))
#define LIBRARY_IS_MAIN_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_MAIN_PAGE))
#define LIBRARY_MAIN_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_MAIN_PAGE, LibraryMainPageClass))

typedef struct _LibraryMainPage LibraryMainPage;
typedef struct _LibraryMainPageClass LibraryMainPageClass;
typedef struct _LibraryHideablePageEntryPrivate LibraryHideablePageEntryPrivate;
typedef struct _PagePrivate PagePrivate;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_FULLSCREEN_WINDOW (fullscreen_window_get_type ())
#define FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindow))
#define FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))
#define IS_FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FULLSCREEN_WINDOW))
#define IS_FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FULLSCREEN_WINDOW))
#define FULLSCREEN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))

typedef struct _FullscreenWindow FullscreenWindow;
typedef struct _FullscreenWindowClass FullscreenWindowClass;

#define TYPE_INJECTION_GROUP (injection_group_get_type ())
#define INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INJECTION_GROUP, InjectionGroup))
#define INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INJECTION_GROUP, InjectionGroupClass))
#define IS_INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INJECTION_GROUP))
#define IS_INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INJECTION_GROUP))
#define INJECTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INJECTION_GROUP, InjectionGroupClass))

typedef struct _InjectionGroup InjectionGroup;
typedef struct _InjectionGroupClass InjectionGroupClass;
typedef struct _CheckerboardPagePrivate CheckerboardPagePrivate;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;

#define TYPE_THUMBNAIL_VIEW (thumbnail_view_get_type ())
#define THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailView))
#define THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))
#define IS_THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_VIEW))
#define IS_THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_VIEW))
#define THUMBNAIL_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))

typedef struct _ThumbnailView ThumbnailView;
typedef struct _ThumbnailViewClass ThumbnailViewClass;

#define TYPE_CHECKERBOARD_ITEM (checkerboard_item_get_type ())
#define CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItem))
#define CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))
#define IS_CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_ITEM))
#define IS_CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_ITEM))
#define CHECKERBOARD_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))

typedef struct _CheckerboardItem CheckerboardItem;
typedef struct _CheckerboardItemClass CheckerboardItemClass;

#define CHECKERBOARD_PAGE_TYPE_ACTIVATOR (checkerboard_page_activator_get_type ())

#define CHECKERBOARD_PAGE_TYPE_KEYBOARD_MODIFIERS (checkerboard_page_keyboard_modifiers_get_type ())
typedef struct _CheckerboardPageKeyboardModifiers CheckerboardPageKeyboardModifiers;

#define TYPE_VIEW_FILTER (view_filter_get_type ())
#define VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_FILTER, ViewFilter))
#define VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_FILTER, ViewFilterClass))
#define IS_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_FILTER))
#define IS_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_FILTER))
#define VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_FILTER, ViewFilterClass))

typedef struct _ViewFilter ViewFilter;
typedef struct _ViewFilterClass ViewFilterClass;

#define TYPE_SEARCH_VIEW_FILTER (search_view_filter_get_type ())
#define SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilter))
#define SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))
#define IS_SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEARCH_VIEW_FILTER))
#define IS_SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEARCH_VIEW_FILTER))
#define SEARCH_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))

typedef struct _SearchViewFilter SearchViewFilter;
typedef struct _SearchViewFilterClass SearchViewFilterClass;

#define CORE_TYPE_TRACKER (core_tracker_get_type ())
#define CORE_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_TRACKER, CoreTracker))
#define CORE_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_TRACKER, CoreTrackerClass))
#define CORE_IS_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_TRACKER))
#define CORE_IS_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_TRACKER))
#define CORE_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_TRACKER, CoreTrackerClass))

typedef struct _CoreTracker CoreTracker;
typedef struct _CoreTrackerClass CoreTrackerClass;

#define CORE_TYPE_VIEW_TRACKER (core_view_tracker_get_type ())
#define CORE_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTracker))
#define CORE_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))
#define CORE_IS_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_VIEW_TRACKER))
#define CORE_IS_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_VIEW_TRACKER))
#define CORE_VIEW_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))

typedef struct _CoreViewTracker CoreViewTracker;
typedef struct _CoreViewTrackerClass CoreViewTrackerClass;
typedef struct _MediaPagePrivate MediaPagePrivate;

#define TYPE_RATING (rating_get_type ())

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;
typedef struct _CollectionPagePrivate CollectionPagePrivate;
typedef struct _LibraryMainPagePrivate LibraryMainPagePrivate;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_MEDIA_COLLECTION_REGISTRY (media_collection_registry_get_type ())
#define MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistry))
#define MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))
#define IS_MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_COLLECTION_REGISTRY))
#define IS_MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_COLLECTION_REGISTRY))
#define MEDIA_COLLECTION_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))

typedef struct _MediaCollectionRegistry MediaCollectionRegistry;
typedef struct _MediaCollectionRegistryClass MediaCollectionRegistryClass;
#define _media_collection_registry_unref0(var) ((var == NULL) ? NULL : (var = (media_collection_registry_unref (var), NULL)))

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;

#define TYPE_VIEW_MANAGER (view_manager_get_type ())
#define VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_MANAGER, ViewManager))
#define VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_MANAGER, ViewManagerClass))
#define IS_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_MANAGER))
#define IS_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_MANAGER))
#define VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_MANAGER, ViewManagerClass))

typedef struct _ViewManager ViewManager;
typedef struct _ViewManagerClass ViewManagerClass;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;

#define VIEW_COLLECTION_TYPE_MONITOR (view_collection_monitor_get_type ())
#define VIEW_COLLECTION_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitor))
#define VIEW_COLLECTION_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitorClass))
#define VIEW_COLLECTION_IS_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEW_COLLECTION_TYPE_MONITOR))
#define VIEW_COLLECTION_IS_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEW_COLLECTION_TYPE_MONITOR))
#define VIEW_COLLECTION_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitorClass))

typedef struct _ViewCollectionMonitor ViewCollectionMonitor;
typedef struct _ViewCollectionMonitorClass ViewCollectionMonitorClass;

#define TYPE_COLLECTION_VIEW_MANAGER (collection_view_manager_get_type ())
#define COLLECTION_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManager))
#define COLLECTION_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManagerClass))
#define IS_COLLECTION_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_VIEW_MANAGER))
#define IS_COLLECTION_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_VIEW_MANAGER))
#define COLLECTION_VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_VIEW_MANAGER, CollectionViewManagerClass))

typedef struct _CollectionViewManager CollectionViewManager;
typedef struct _CollectionViewManagerClass CollectionViewManagerClass;
#define _view_collection_monitor_unref0(var) ((var == NULL) ? NULL : (var = (view_collection_monitor_unref (var), NULL)))
#define _view_manager_unref0(var) ((var == NULL) ? NULL : (var = (view_manager_unref (var), NULL)))
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

struct _SidebarBranch {
	GObject parent_instance;
	SidebarBranchPrivate * priv;
};

struct _SidebarBranchClass {
	GObjectClass parent_class;
};

struct _LibraryBranch {
	SidebarBranch parent_instance;
	LibraryBranchPrivate * priv;
};

struct _LibraryBranchClass {
	SidebarBranchClass parent_class;
};

struct _LibraryBranchPrivate {
	LibraryPhotosEntry* _photos_entry;
	LibraryFlaggedSidebarEntry* _flagged_entry;
	LibraryLastImportSidebarEntry* _last_imported_entry;
	LibraryImportQueueSidebarEntry* _import_queue_entry;
	LibraryOfflineSidebarEntry* _offline_entry;
	LibraryTrashSidebarEntry* _trash_entry;
};

typedef enum  {
	LIBRARY_BRANCH_ENTRY_POSITION_PHOTOS,
	LIBRARY_BRANCH_ENTRY_POSITION_FLAGGED,
	LIBRARY_BRANCH_ENTRY_POSITION_LAST_IMPORTED,
	LIBRARY_BRANCH_ENTRY_POSITION_IMPORT_QUEUE,
	LIBRARY_BRANCH_ENTRY_POSITION_OFFLINE,
	LIBRARY_BRANCH_ENTRY_POSITION_TRASH
} LibraryBranchEntryPosition;

struct _SidebarEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_sidebar_name) (SidebarEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarEntry* self);
	gchar* (*get_sidebar_icon) (SidebarEntry* self);
	gchar* (*to_string) (SidebarEntry* self);
	void (*grafted) (SidebarEntry* self, SidebarTree* tree);
	void (*pruned) (SidebarEntry* self, SidebarTree* tree);
};

typedef enum  {
	SIDEBAR_BRANCH_OPTIONS_NONE = 0,
	SIDEBAR_BRANCH_OPTIONS_HIDE_IF_EMPTY = 1 << 0,
	SIDEBAR_BRANCH_OPTIONS_AUTO_OPEN_ON_NEW_CHILD = 1 << 1,
	SIDEBAR_BRANCH_OPTIONS_STARTUP_EXPAND_TO_FIRST_CHILD = 1 << 2,
	SIDEBAR_BRANCH_OPTIONS_STARTUP_OPEN_GROUPING = 1 << 3
} SidebarBranchOptions;

struct _SidebarSelectableEntryIface {
	GTypeInterface parent_iface;
};

struct _SidebarPageRepresentativeIface {
	GTypeInterface parent_iface;
	gboolean (*has_page) (SidebarPageRepresentative* self);
	Page* (*get_page) (SidebarPageRepresentative* self);
};

struct _SidebarContextableIface {
	GTypeInterface parent_iface;
	GtkMenu* (*get_sidebar_context_menu) (SidebarContextable* self, GdkEventButton* event);
};

struct _SidebarSimplePageEntry {
	GObject parent_instance;
	SidebarSimplePageEntryPrivate * priv;
};

struct _SidebarSimplePageEntryClass {
	GObjectClass parent_class;
	gchar* (*get_sidebar_name) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_icon) (SidebarSimplePageEntry* self);
	gchar* (*to_string) (SidebarSimplePageEntry* self);
	Page* (*create_page) (SidebarSimplePageEntry* self);
};

struct _LibraryPhotosEntry {
	SidebarSimplePageEntry parent_instance;
	LibraryPhotosEntryPrivate * priv;
};

struct _LibraryPhotosEntryClass {
	SidebarSimplePageEntryClass parent_class;
};

typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);
struct _LibraryHideablePageEntry {
	SidebarSimplePageEntry parent_instance;
	LibraryHideablePageEntryPrivate * priv;
};

struct _LibraryHideablePageEntryClass {
	SidebarSimplePageEntryClass parent_class;
};

struct _LibraryHideablePageEntryPrivate {
	gboolean show_entry;
};

struct _Page {
	GtkScrolledWindow parent_instance;
	PagePrivate * priv;
	GtkUIManager* ui;
	GtkToolbar* toolbar;
	gboolean in_view;
};

struct _PageClass {
	GtkScrolledWindowClass parent_class;
	void (*set_page_name) (Page* self, const gchar* page_name);
	void (*set_container) (Page* self, GtkWindow* container);
	void (*clear_container) (Page* self);
	GtkMenuBar* (*get_menubar) (Page* self);
	GtkWidget* (*get_page_ui_widget) (Page* self, const gchar* path);
	GtkToolbar* (*get_toolbar) (Page* self);
	GtkMenu* (*get_page_context_menu) (Page* self);
	void (*switching_from) (Page* self);
	void (*switched_to) (Page* self);
	void (*ready) (Page* self);
	void (*switching_to_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*returning_from_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*init_collect_ui_filenames) (Page* self, GeeList* ui_filenames);
	GtkActionEntry* (*init_collect_action_entries) (Page* self, int* result_length1);
	GtkToggleActionEntry* (*init_collect_toggle_action_entries) (Page* self, int* result_length1);
	void (*register_radio_actions) (Page* self, GtkActionGroup* action_group);
	InjectionGroup** (*init_collect_injection_groups) (Page* self, int* result_length1);
	void (*init_actions) (Page* self, gint selected_count, gint count);
	void (*update_actions) (Page* self, gint selected_count, gint count);
	gboolean (*source_drag_failed) (Page* self, GdkDragContext* context, GtkDragResult drag_result);
	gboolean (*on_left_click) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_click) (Page* self, GdkEventButton* event);
	gboolean (*on_right_click) (Page* self, GdkEventButton* event);
	gboolean (*on_left_released) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_released) (Page* self, GdkEventButton* event);
	gboolean (*on_right_released) (Page* self, GdkEventButton* event);
	gboolean (*on_ctrl_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_ctrl_released) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_released) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_released) (Page* self, GdkEventKey* event);
	gboolean (*on_super_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_super_released) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_released) (Page* self, GdkEventKey* event);
	void (*on_move) (Page* self, GdkRectangle* rect);
	void (*on_move_start) (Page* self, GdkRectangle* rect);
	void (*on_move_finished) (Page* self, GdkRectangle* rect);
	void (*on_resize) (Page* self, GdkRectangle* rect);
	void (*on_resize_start) (Page* self, GdkRectangle* rect);
	void (*on_resize_finished) (Page* self, GdkRectangle* rect);
	gboolean (*on_configure) (Page* self, GdkEventConfigure* event, GdkRectangle* rect);
	gboolean (*on_motion) (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
	gboolean (*on_leave_notify_event) (Page* self);
	gboolean (*on_mousewheel_up) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_down) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_left) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_right) (Page* self, GdkEventScroll* event);
	gboolean (*on_context_keypress) (Page* self);
	gboolean (*on_context_buttonpress) (Page* self, GdkEventButton* event);
	gboolean (*on_context_invoked) (Page* self);
	void (*set_page_cursor) (Page* self, GdkCursorType cursor_type);
};

typedef enum  {
	CHECKERBOARD_PAGE_ACTIVATOR_KEYBOARD,
	CHECKERBOARD_PAGE_ACTIVATOR_MOUSE
} CheckerboardPageActivator;

struct _CheckerboardPageKeyboardModifiers {
	gboolean ctrl_pressed;
	gboolean alt_pressed;
	gboolean shift_pressed;
	gboolean super_pressed;
};

struct _CheckerboardPage {
	Page parent_instance;
	CheckerboardPagePrivate * priv;
	CheckerboardItem* anchor;
	CheckerboardItem* cursor;
};

struct _CheckerboardPageClass {
	PageClass parent_class;
	GtkMenu* (*get_item_context_menu) (CheckerboardPage* self);
	gchar* (*get_view_empty_message) (CheckerboardPage* self);
	gchar* (*get_filter_no_match_message) (CheckerboardPage* self);
	void (*on_item_activated) (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers);
	SearchViewFilter* (*get_search_view_filter) (CheckerboardPage* self);
	CoreViewTracker* (*get_view_tracker) (CheckerboardPage* self);
	gboolean (*on_mouse_over) (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask);
	void (*set_display_titles) (CheckerboardPage* self, gboolean display);
	void (*set_display_comments) (CheckerboardPage* self, gboolean display);
};

typedef enum  {
	RATING_REJECTED = -1,
	RATING_UNRATED = 0,
	RATING_ONE = 1,
	RATING_TWO = 2,
	RATING_THREE = 3,
	RATING_FOUR = 4,
	RATING_FIVE = 5
} Rating;

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _MediaPage {
	CheckerboardPage parent_instance;
	MediaPagePrivate * priv;
};

struct _MediaPageClass {
	CheckerboardPageClass parent_class;
	void (*on_zoom_changed) (MediaPage* self);
	void (*on_export) (MediaPage* self);
	void (*on_increase_size) (MediaPage* self);
	void (*on_decrease_size) (MediaPage* self);
	void (*on_increase_rating) (MediaPage* self);
	void (*on_decrease_rating) (MediaPage* self);
	void (*on_set_rating) (MediaPage* self, Rating rating);
	void (*on_rate_rejected) (MediaPage* self);
	void (*on_rate_unrated) (MediaPage* self);
	void (*on_rate_one) (MediaPage* self);
	void (*on_rate_two) (MediaPage* self);
	void (*on_rate_three) (MediaPage* self);
	void (*on_rate_four) (MediaPage* self);
	void (*on_rate_five) (MediaPage* self);
	void (*on_move_to_trash) (MediaPage* self);
	void (*on_edit_title) (MediaPage* self);
	void (*on_edit_comment) (MediaPage* self);
	void (*on_display_titles) (MediaPage* self, GtkAction* action);
	void (*on_display_comments) (MediaPage* self, GtkAction* action);
	void (*on_display_ratings) (MediaPage* self, GtkAction* action);
	void (*on_display_tags) (MediaPage* self, GtkAction* action);
	void (*get_config_photos_sort) (MediaPage* self, gboolean* sort_order, gint* sort_by);
	void (*set_config_photos_sort) (MediaPage* self, gboolean sort_order, gint sort_by);
	void (*on_sort_changed) (MediaPage* self);
	void (*developer_changed) (MediaPage* self, RawDeveloper rd);
	DataView* (*create_thumbnail) (MediaPage* self, DataSource* source);
};

struct _CollectionPage {
	MediaPage parent_instance;
	CollectionPagePrivate * priv;
};

struct _CollectionPageClass {
	MediaPageClass parent_class;
};

struct _LibraryMainPage {
	CollectionPage parent_instance;
	LibraryMainPagePrivate * priv;
};

struct _LibraryMainPageClass {
	CollectionPageClass parent_class;
};


static gpointer library_branch_parent_class = NULL;
static gpointer library_photos_entry_parent_class = NULL;
static gpointer library_hideable_page_entry_parent_class = NULL;
static gpointer library_main_page_parent_class = NULL;

GType sidebar_branch_get_type (void) G_GNUC_CONST;
GType library_branch_get_type (void) G_GNUC_CONST;
GType sidebar_simple_page_entry_get_type (void) G_GNUC_CONST;
GType library_photos_entry_get_type (void) G_GNUC_CONST;
GType library_hideable_page_entry_get_type (void) G_GNUC_CONST;
GType library_flagged_sidebar_entry_get_type (void) G_GNUC_CONST;
GType library_last_import_sidebar_entry_get_type (void) G_GNUC_CONST;
GType library_import_queue_sidebar_entry_get_type (void) G_GNUC_CONST;
GType library_offline_sidebar_entry_get_type (void) G_GNUC_CONST;
GType library_trash_sidebar_entry_get_type (void) G_GNUC_CONST;
#define LIBRARY_BRANCH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), LIBRARY_TYPE_BRANCH, LibraryBranchPrivate))
enum  {
	LIBRARY_BRANCH_DUMMY_PROPERTY,
	LIBRARY_BRANCH_PHOTOS_ENTRY,
	LIBRARY_BRANCH_FLAGGED_ENTRY,
	LIBRARY_BRANCH_LAST_IMPORTED_ENTRY,
	LIBRARY_BRANCH_IMPORT_QUEUE_ENTRY,
	LIBRARY_BRANCH_OFFLINE_ENTRY,
	LIBRARY_BRANCH_TRASH_ENTRY
};
static GType library_branch_entry_position_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define LIBRARY_BRANCH_POSITION_DATA "x-photos-entry-position"
LibraryBranch* library_branch_new (void);
LibraryBranch* library_branch_construct (GType object_type);
SidebarHeader* sidebar_header_new (const gchar* name, gboolean emphasized);
SidebarHeader* sidebar_header_construct (GType object_type, const gchar* name, gboolean emphasized);
GType sidebar_grouping_get_type (void) G_GNUC_CONST;
GType sidebar_header_get_type (void) G_GNUC_CONST;
GType sidebar_tree_get_type (void) G_GNUC_CONST;
GType sidebar_entry_get_type (void) G_GNUC_CONST;
GType sidebar_branch_options_get_type (void) G_GNUC_CONST;
static gint library_branch_comparator (SidebarEntry* a, SidebarEntry* b);
static gint _library_branch_comparator_gcompare_func (gconstpointer a, gconstpointer b);
SidebarBranch* sidebar_branch_new (SidebarEntry* root, SidebarBranchOptions options, GCompareFunc default_comparator, GCompareFunc root_comparator);
SidebarBranch* sidebar_branch_construct (GType object_type, SidebarEntry* root, SidebarBranchOptions options, GCompareFunc default_comparator, GCompareFunc root_comparator);
LibraryPhotosEntry* library_photos_entry_new (void);
LibraryPhotosEntry* library_photos_entry_construct (GType object_type);
static void library_branch_set_photos_entry (LibraryBranch* self, LibraryPhotosEntry* value);
LibraryTrashSidebarEntry* library_trash_sidebar_entry_new (void);
LibraryTrashSidebarEntry* library_trash_sidebar_entry_construct (GType object_type);
static void library_branch_set_trash_entry (LibraryBranch* self, LibraryTrashSidebarEntry* value);
LibraryLastImportSidebarEntry* library_last_import_sidebar_entry_new (void);
LibraryLastImportSidebarEntry* library_last_import_sidebar_entry_construct (GType object_type);
static void library_branch_set_last_imported_entry (LibraryBranch* self, LibraryLastImportSidebarEntry* value);
LibraryFlaggedSidebarEntry* library_flagged_sidebar_entry_new (void);
LibraryFlaggedSidebarEntry* library_flagged_sidebar_entry_construct (GType object_type);
static void library_branch_set_flagged_entry (LibraryBranch* self, LibraryFlaggedSidebarEntry* value);
LibraryOfflineSidebarEntry* library_offline_sidebar_entry_new (void);
LibraryOfflineSidebarEntry* library_offline_sidebar_entry_construct (GType object_type);
static void library_branch_set_offline_entry (LibraryBranch* self, LibraryOfflineSidebarEntry* value);
LibraryImportQueueSidebarEntry* library_import_queue_sidebar_entry_new (void);
LibraryImportQueueSidebarEntry* library_import_queue_sidebar_entry_construct (GType object_type);
static void library_branch_set_import_queue_entry (LibraryBranch* self, LibraryImportQueueSidebarEntry* value);
static void library_branch_insert (LibraryBranch* self, SidebarEntry* entry, gint position);
LibraryPhotosEntry* library_branch_get_photos_entry (LibraryBranch* self);
LibraryTrashSidebarEntry* library_branch_get_trash_entry (LibraryBranch* self);
LibraryFlaggedSidebarEntry* library_branch_get_flagged_entry (LibraryBranch* self);
static void library_branch_on_flagged_visibility_changed (LibraryBranch* self);
static void _library_branch_on_flagged_visibility_changed_library_hideable_page_entry_visibility_changed (LibraryHideablePageEntry* _sender, gboolean visible, gpointer self);
LibraryLastImportSidebarEntry* library_branch_get_last_imported_entry (LibraryBranch* self);
static void library_branch_on_last_imported_visibility_changed (LibraryBranch* self);
static void _library_branch_on_last_imported_visibility_changed_library_hideable_page_entry_visibility_changed (LibraryHideablePageEntry* _sender, gboolean visible, gpointer self);
LibraryImportQueueSidebarEntry* library_branch_get_import_queue_entry (LibraryBranch* self);
static void library_branch_on_import_queue_visibility_changed (LibraryBranch* self);
static void _library_branch_on_import_queue_visibility_changed_library_hideable_page_entry_visibility_changed (LibraryHideablePageEntry* _sender, gboolean visible, gpointer self);
LibraryOfflineSidebarEntry* library_branch_get_offline_entry (LibraryBranch* self);
static void library_branch_on_offline_visibility_changed (LibraryBranch* self);
static void _library_branch_on_offline_visibility_changed_library_hideable_page_entry_visibility_changed (LibraryHideablePageEntry* _sender, gboolean visible, gpointer self);
void sidebar_branch_graft (SidebarBranch* self, SidebarEntry* parent, SidebarEntry* entry, GCompareFunc comparator);
SidebarEntry* sidebar_branch_get_root (SidebarBranch* self);
static void library_branch_update_entry_visibility (LibraryBranch* self, LibraryHideablePageEntry* entry, gint position);
gboolean library_hideable_page_entry_get_visible (LibraryHideablePageEntry* self);
gboolean sidebar_branch_has_entry (SidebarBranch* self, SidebarEntry* entry);
void sidebar_branch_prune (SidebarBranch* self, SidebarEntry* entry);
static void library_branch_finalize (GObject* obj);
static void _vala_library_branch_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_library_branch_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType sidebar_selectable_entry_get_type (void) G_GNUC_CONST;
GType page_get_type (void) G_GNUC_CONST;
GType sidebar_page_representative_get_type (void) G_GNUC_CONST;
GType sidebar_contextable_get_type (void) G_GNUC_CONST;
enum  {
	LIBRARY_PHOTOS_ENTRY_DUMMY_PROPERTY
};
SidebarSimplePageEntry* sidebar_simple_page_entry_construct (GType object_type);
static gchar* library_photos_entry_real_get_sidebar_name (SidebarSimplePageEntry* base);
static gchar* library_photos_entry_real_get_sidebar_icon (SidebarSimplePageEntry* base);
#define RESOURCES_ICON_PHOTOS "shotwell"
static Page* library_photos_entry_real_create_page (SidebarSimplePageEntry* base);
LibraryMainPage* library_main_page_new (ProgressMonitor monitor, void* monitor_target);
LibraryMainPage* library_main_page_construct (GType object_type, ProgressMonitor monitor, void* monitor_target);
GType checkerboard_page_get_type (void) G_GNUC_CONST;
GType media_page_get_type (void) G_GNUC_CONST;
GType collection_page_get_type (void) G_GNUC_CONST;
GType library_main_page_get_type (void) G_GNUC_CONST;
#define LIBRARY_HIDEABLE_PAGE_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntryPrivate))
enum  {
	LIBRARY_HIDEABLE_PAGE_ENTRY_DUMMY_PROPERTY,
	LIBRARY_HIDEABLE_PAGE_ENTRY_VISIBLE
};
LibraryHideablePageEntry* library_hideable_page_entry_construct (GType object_type);
void library_hideable_page_entry_set_visible (LibraryHideablePageEntry* self, gboolean value);
static void library_hideable_page_entry_finalize (GObject* obj);
static void _vala_library_hideable_page_entry_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_library_hideable_page_entry_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType page_window_get_type (void) G_GNUC_CONST;
GType fullscreen_window_get_type (void) G_GNUC_CONST;
gpointer injection_group_ref (gpointer instance);
void injection_group_unref (gpointer instance);
GParamSpec* param_spec_injection_group (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_injection_group (GValue* value, gpointer v_object);
void value_take_injection_group (GValue* value, gpointer v_object);
gpointer value_get_injection_group (const GValue* value);
GType injection_group_get_type (void) G_GNUC_CONST;
GType data_object_get_type (void) G_GNUC_CONST;
GType data_view_get_type (void) G_GNUC_CONST;
GType thumbnail_view_get_type (void) G_GNUC_CONST;
GType checkerboard_item_get_type (void) G_GNUC_CONST;
GType checkerboard_page_activator_get_type (void) G_GNUC_CONST;
GType checkerboard_page_keyboard_modifiers_get_type (void) G_GNUC_CONST;
CheckerboardPageKeyboardModifiers* checkerboard_page_keyboard_modifiers_dup (const CheckerboardPageKeyboardModifiers* self);
void checkerboard_page_keyboard_modifiers_free (CheckerboardPageKeyboardModifiers* self);
gpointer view_filter_ref (gpointer instance);
void view_filter_unref (gpointer instance);
GParamSpec* param_spec_view_filter (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_view_filter (GValue* value, gpointer v_object);
void value_take_view_filter (GValue* value, gpointer v_object);
gpointer value_get_view_filter (const GValue* value);
GType view_filter_get_type (void) G_GNUC_CONST;
GType search_view_filter_get_type (void) G_GNUC_CONST;
gpointer core_tracker_ref (gpointer instance);
void core_tracker_unref (gpointer instance);
GParamSpec* core_param_spec_tracker (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void core_value_set_tracker (GValue* value, gpointer v_object);
void core_value_take_tracker (GValue* value, gpointer v_object);
gpointer core_value_get_tracker (const GValue* value);
GType core_tracker_get_type (void) G_GNUC_CONST;
GType core_view_tracker_get_type (void) G_GNUC_CONST;
GType rating_get_type (void) G_GNUC_CONST;
GType raw_developer_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
enum  {
	LIBRARY_MAIN_PAGE_DUMMY_PROPERTY
};
#define LIBRARY_MAIN_PAGE_NAME _ ("Library")
CollectionPage* collection_page_construct (GType object_type, const gchar* page_name);
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType media_source_collection_get_type (void) G_GNUC_CONST;
gpointer media_collection_registry_ref (gpointer instance);
void media_collection_registry_unref (gpointer instance);
GParamSpec* param_spec_media_collection_registry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_media_collection_registry (GValue* value, gpointer v_object);
void value_take_media_collection_registry (GValue* value, gpointer v_object);
gpointer value_get_media_collection_registry (const GValue* value);
GType media_collection_registry_get_type (void) G_GNUC_CONST;
MediaCollectionRegistry* media_collection_registry_get_instance (void);
GeeCollection* media_collection_registry_get_all (MediaCollectionRegistry* self);
GType view_collection_get_type (void) G_GNUC_CONST;
ViewCollection* page_get_view (Page* self);
gpointer view_manager_ref (gpointer instance);
void view_manager_unref (gpointer instance);
GParamSpec* param_spec_view_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_view_manager (GValue* value, gpointer v_object);
void value_take_view_manager (GValue* value, gpointer v_object);
gpointer value_get_view_manager (const GValue* value);
GType view_manager_get_type (void) G_GNUC_CONST;
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_alteration (GValue* value, gpointer v_object);
void value_take_alteration (GValue* value, gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
gpointer view_collection_monitor_ref (gpointer instance);
void view_collection_monitor_unref (gpointer instance);
GParamSpec* view_collection_param_spec_monitor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void view_collection_value_set_monitor (GValue* value, gpointer v_object);
void view_collection_value_take_monitor (GValue* value, gpointer v_object);
gpointer view_collection_value_get_monitor (const GValue* value);
GType view_collection_monitor_get_type (void) G_GNUC_CONST;
ViewCollectionMonitor* view_collection_monitor_source_collection (ViewCollection* self, SourceCollection* sources, ViewManager* manager, Alteration* prereq, GeeCollection* initial, ProgressMonitor progress_monitor, void* progress_monitor_target);
CollectionViewManager* collection_view_manager_new (CollectionPage* page);
CollectionViewManager* collection_view_manager_construct (GType object_type, CollectionPage* page);
GType collection_view_manager_get_type (void) G_GNUC_CONST;
static void library_main_page_real_get_config_photos_sort (MediaPage* base, gboolean* sort_order, gint* sort_by);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
void configuration_facade_get_library_photos_sort (ConfigurationFacade* self, gboolean* sort_order, gint* sort_by);
static void library_main_page_real_set_config_photos_sort (MediaPage* base, gboolean sort_order, gint sort_by);
void configuration_facade_set_library_photos_sort (ConfigurationFacade* self, gboolean sort_order, gint sort_by);


static GType library_branch_entry_position_get_type (void) {
	static volatile gsize library_branch_entry_position_type_id__volatile = 0;
	if (g_once_init_enter (&library_branch_entry_position_type_id__volatile)) {
		static const GEnumValue values[] = {{LIBRARY_BRANCH_ENTRY_POSITION_PHOTOS, "LIBRARY_BRANCH_ENTRY_POSITION_PHOTOS", "photos"}, {LIBRARY_BRANCH_ENTRY_POSITION_FLAGGED, "LIBRARY_BRANCH_ENTRY_POSITION_FLAGGED", "flagged"}, {LIBRARY_BRANCH_ENTRY_POSITION_LAST_IMPORTED, "LIBRARY_BRANCH_ENTRY_POSITION_LAST_IMPORTED", "last-imported"}, {LIBRARY_BRANCH_ENTRY_POSITION_IMPORT_QUEUE, "LIBRARY_BRANCH_ENTRY_POSITION_IMPORT_QUEUE", "import-queue"}, {LIBRARY_BRANCH_ENTRY_POSITION_OFFLINE, "LIBRARY_BRANCH_ENTRY_POSITION_OFFLINE", "offline"}, {LIBRARY_BRANCH_ENTRY_POSITION_TRASH, "LIBRARY_BRANCH_ENTRY_POSITION_TRASH", "trash"}, {0, NULL, NULL}};
		GType library_branch_entry_position_type_id;
		library_branch_entry_position_type_id = g_enum_register_static ("LibraryBranchEntryPosition", values);
		g_once_init_leave (&library_branch_entry_position_type_id__volatile, library_branch_entry_position_type_id);
	}
	return library_branch_entry_position_type_id__volatile;
}


static gint _library_branch_comparator_gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = library_branch_comparator ((SidebarEntry*) a, (SidebarEntry*) b);
#line 30 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 997 "Branch.c"
}


static void _library_branch_on_flagged_visibility_changed_library_hideable_page_entry_visibility_changed (LibraryHideablePageEntry* _sender, gboolean visible, gpointer self) {
#line 43 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_on_flagged_visibility_changed ((LibraryBranch*) self);
#line 1004 "Branch.c"
}


static void _library_branch_on_last_imported_visibility_changed_library_hideable_page_entry_visibility_changed (LibraryHideablePageEntry* _sender, gboolean visible, gpointer self) {
#line 46 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_on_last_imported_visibility_changed ((LibraryBranch*) self);
#line 1011 "Branch.c"
}


static void _library_branch_on_import_queue_visibility_changed_library_hideable_page_entry_visibility_changed (LibraryHideablePageEntry* _sender, gboolean visible, gpointer self) {
#line 49 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_on_import_queue_visibility_changed ((LibraryBranch*) self);
#line 1018 "Branch.c"
}


static void _library_branch_on_offline_visibility_changed_library_hideable_page_entry_visibility_changed (LibraryHideablePageEntry* _sender, gboolean visible, gpointer self) {
#line 52 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_on_offline_visibility_changed ((LibraryBranch*) self);
#line 1025 "Branch.c"
}


LibraryBranch* library_branch_construct (GType object_type) {
	LibraryBranch * self = NULL;
	const gchar* _tmp0_ = NULL;
	SidebarHeader* _tmp1_ = NULL;
	SidebarHeader* _tmp2_ = NULL;
	LibraryPhotosEntry* _tmp3_ = NULL;
	LibraryPhotosEntry* _tmp4_ = NULL;
	LibraryTrashSidebarEntry* _tmp5_ = NULL;
	LibraryTrashSidebarEntry* _tmp6_ = NULL;
	LibraryLastImportSidebarEntry* _tmp7_ = NULL;
	LibraryLastImportSidebarEntry* _tmp8_ = NULL;
	LibraryFlaggedSidebarEntry* _tmp9_ = NULL;
	LibraryFlaggedSidebarEntry* _tmp10_ = NULL;
	LibraryOfflineSidebarEntry* _tmp11_ = NULL;
	LibraryOfflineSidebarEntry* _tmp12_ = NULL;
	LibraryImportQueueSidebarEntry* _tmp13_ = NULL;
	LibraryImportQueueSidebarEntry* _tmp14_ = NULL;
	LibraryPhotosEntry* _tmp15_ = NULL;
	LibraryTrashSidebarEntry* _tmp16_ = NULL;
	LibraryFlaggedSidebarEntry* _tmp17_ = NULL;
	LibraryLastImportSidebarEntry* _tmp18_ = NULL;
	LibraryImportQueueSidebarEntry* _tmp19_ = NULL;
	LibraryOfflineSidebarEntry* _tmp20_ = NULL;
#line 30 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = _ ("Library");
#line 30 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = sidebar_header_new (_tmp0_, TRUE);
#line 30 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp2_ = _tmp1_;
#line 30 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = (LibraryBranch*) sidebar_branch_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SIDEBAR_TYPE_ENTRY, SidebarEntry), SIDEBAR_BRANCH_OPTIONS_STARTUP_OPEN_GROUPING, _library_branch_comparator_gcompare_func, NULL);
#line 30 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp2_);
#line 33 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp3_ = library_photos_entry_new ();
#line 33 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp4_ = _tmp3_;
#line 33 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_set_photos_entry (self, _tmp4_);
#line 33 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp4_);
#line 34 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp5_ = library_trash_sidebar_entry_new ();
#line 34 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp6_ = _tmp5_;
#line 34 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_set_trash_entry (self, _tmp6_);
#line 34 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp6_);
#line 35 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp7_ = library_last_import_sidebar_entry_new ();
#line 35 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp8_ = _tmp7_;
#line 35 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_set_last_imported_entry (self, _tmp8_);
#line 35 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp8_);
#line 36 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp9_ = library_flagged_sidebar_entry_new ();
#line 36 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp10_ = _tmp9_;
#line 36 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_set_flagged_entry (self, _tmp10_);
#line 36 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp10_);
#line 37 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp11_ = library_offline_sidebar_entry_new ();
#line 37 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp12_ = _tmp11_;
#line 37 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_set_offline_entry (self, _tmp12_);
#line 37 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp12_);
#line 38 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp13_ = library_import_queue_sidebar_entry_new ();
#line 38 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp14_ = _tmp13_;
#line 38 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_set_import_queue_entry (self, _tmp14_);
#line 38 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp14_);
#line 40 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp15_ = self->priv->_photos_entry;
#line 40 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_insert (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, SIDEBAR_TYPE_ENTRY, SidebarEntry), (gint) LIBRARY_BRANCH_ENTRY_POSITION_PHOTOS);
#line 41 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp16_ = self->priv->_trash_entry;
#line 41 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_insert (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, SIDEBAR_TYPE_ENTRY, SidebarEntry), (gint) LIBRARY_BRANCH_ENTRY_POSITION_TRASH);
#line 43 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp17_ = self->priv->_flagged_entry;
#line 43 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry), "visibility-changed", (GCallback) _library_branch_on_flagged_visibility_changed_library_hideable_page_entry_visibility_changed, self, 0);
#line 44 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_on_flagged_visibility_changed (self);
#line 46 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp18_ = self->priv->_last_imported_entry;
#line 46 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry), "visibility-changed", (GCallback) _library_branch_on_last_imported_visibility_changed_library_hideable_page_entry_visibility_changed, self, 0);
#line 47 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_on_last_imported_visibility_changed (self);
#line 49 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp19_ = self->priv->_import_queue_entry;
#line 49 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry), "visibility-changed", (GCallback) _library_branch_on_import_queue_visibility_changed_library_hideable_page_entry_visibility_changed, self, 0);
#line 50 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_on_import_queue_visibility_changed (self);
#line 52 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp20_ = self->priv->_offline_entry;
#line 52 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry), "visibility-changed", (GCallback) _library_branch_on_offline_visibility_changed_library_hideable_page_entry_visibility_changed, self, 0);
#line 53 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_on_offline_visibility_changed (self);
#line 29 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return self;
#line 1144 "Branch.c"
}


LibraryBranch* library_branch_new (void) {
#line 29 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return library_branch_construct (LIBRARY_TYPE_BRANCH);
#line 1151 "Branch.c"
}


static void library_branch_insert (LibraryBranch* self, SidebarEntry* entry, gint position) {
	SidebarEntry* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	SidebarEntry* _tmp2_ = NULL;
	SidebarEntry* _tmp3_ = NULL;
	SidebarEntry* _tmp4_ = NULL;
#line 56 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 56 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 57 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = entry;
#line 57 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = position;
#line 57 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_set_data_full (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), LIBRARY_BRANCH_POSITION_DATA, (gpointer) ((gintptr) _tmp1_), NULL);
#line 58 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp2_ = sidebar_branch_get_root (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch));
#line 58 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp3_ = _tmp2_;
#line 58 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp4_ = entry;
#line 58 "/home/jens/Source/shotwell/src/library/Branch.vala"
	sidebar_branch_graft (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), _tmp3_, _tmp4_, NULL);
#line 58 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp3_);
#line 1181 "Branch.c"
}


static void library_branch_on_flagged_visibility_changed (LibraryBranch* self) {
	LibraryFlaggedSidebarEntry* _tmp0_ = NULL;
#line 61 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 62 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_flagged_entry;
#line 62 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_update_entry_visibility (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry), (gint) LIBRARY_BRANCH_ENTRY_POSITION_FLAGGED);
#line 1193 "Branch.c"
}


static void library_branch_on_last_imported_visibility_changed (LibraryBranch* self) {
	LibraryLastImportSidebarEntry* _tmp0_ = NULL;
#line 65 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 66 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_last_imported_entry;
#line 66 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_update_entry_visibility (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry), (gint) LIBRARY_BRANCH_ENTRY_POSITION_LAST_IMPORTED);
#line 1205 "Branch.c"
}


static void library_branch_on_import_queue_visibility_changed (LibraryBranch* self) {
	LibraryImportQueueSidebarEntry* _tmp0_ = NULL;
#line 69 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 70 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_import_queue_entry;
#line 70 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_update_entry_visibility (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry), (gint) LIBRARY_BRANCH_ENTRY_POSITION_IMPORT_QUEUE);
#line 1217 "Branch.c"
}


static void library_branch_on_offline_visibility_changed (LibraryBranch* self) {
	LibraryOfflineSidebarEntry* _tmp0_ = NULL;
#line 73 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 74 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_offline_entry;
#line 74 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_update_entry_visibility (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry), (gint) LIBRARY_BRANCH_ENTRY_POSITION_OFFLINE);
#line 1229 "Branch.c"
}


static void library_branch_update_entry_visibility (LibraryBranch* self, LibraryHideablePageEntry* entry, gint position) {
	LibraryHideablePageEntry* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 77 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 77 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_HIDEABLE_PAGE_ENTRY (entry));
#line 78 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = entry;
#line 78 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = library_hideable_page_entry_get_visible (_tmp0_);
#line 78 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp2_ = _tmp1_;
#line 78 "/home/jens/Source/shotwell/src/library/Branch.vala"
	if (_tmp2_) {
#line 1249 "Branch.c"
		LibraryHideablePageEntry* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 79 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp3_ = entry;
#line 79 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp4_ = sidebar_branch_has_entry (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 79 "/home/jens/Source/shotwell/src/library/Branch.vala"
		if (!_tmp4_) {
#line 1258 "Branch.c"
			LibraryHideablePageEntry* _tmp5_ = NULL;
			gint _tmp6_ = 0;
#line 80 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp5_ = entry;
#line 80 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp6_ = position;
#line 80 "/home/jens/Source/shotwell/src/library/Branch.vala"
			library_branch_insert (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SIDEBAR_TYPE_ENTRY, SidebarEntry), _tmp6_);
#line 1267 "Branch.c"
		}
	} else {
		LibraryHideablePageEntry* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
#line 81 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp7_ = entry;
#line 81 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp8_ = sidebar_branch_has_entry (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 81 "/home/jens/Source/shotwell/src/library/Branch.vala"
		if (_tmp8_) {
#line 1278 "Branch.c"
			LibraryHideablePageEntry* _tmp9_ = NULL;
#line 82 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp9_ = entry;
#line 82 "/home/jens/Source/shotwell/src/library/Branch.vala"
			sidebar_branch_prune (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 1284 "Branch.c"
		}
	}
}


static gint library_branch_comparator (SidebarEntry* a, SidebarEntry* b) {
	gint result = 0;
	SidebarEntry* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	SidebarEntry* _tmp2_ = NULL;
	gconstpointer _tmp3_ = NULL;
#line 86 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (a), 0);
#line 86 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (b), 0);
#line 87 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = a;
#line 87 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = g_object_get_data (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), LIBRARY_BRANCH_POSITION_DATA);
#line 87 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp2_ = b;
#line 87 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp3_ = g_object_get_data (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, G_TYPE_OBJECT, GObject), LIBRARY_BRANCH_POSITION_DATA);
#line 87 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = ((gint) ((gintptr) _tmp1_)) - ((gint) ((gintptr) _tmp3_));
#line 87 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1312 "Branch.c"
}


LibraryPhotosEntry* library_branch_get_photos_entry (LibraryBranch* self) {
	LibraryPhotosEntry* result;
	LibraryPhotosEntry* _tmp0_ = NULL;
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (LIBRARY_IS_BRANCH (self), NULL);
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_photos_entry;
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp0_;
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1327 "Branch.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return self ? g_object_ref (self) : NULL;
#line 1334 "Branch.c"
}


static void library_branch_set_photos_entry (LibraryBranch* self, LibraryPhotosEntry* value) {
	LibraryPhotosEntry* _tmp0_ = NULL;
	LibraryPhotosEntry* _tmp1_ = NULL;
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = value;
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_photos_entry);
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv->_photos_entry = _tmp1_;
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_notify ((GObject *) self, "photos-entry");
#line 1353 "Branch.c"
}


LibraryFlaggedSidebarEntry* library_branch_get_flagged_entry (LibraryBranch* self) {
	LibraryFlaggedSidebarEntry* result;
	LibraryFlaggedSidebarEntry* _tmp0_ = NULL;
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (LIBRARY_IS_BRANCH (self), NULL);
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_flagged_entry;
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp0_;
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1368 "Branch.c"
}


static void library_branch_set_flagged_entry (LibraryBranch* self, LibraryFlaggedSidebarEntry* value) {
	LibraryFlaggedSidebarEntry* _tmp0_ = NULL;
	LibraryFlaggedSidebarEntry* _tmp1_ = NULL;
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = value;
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_flagged_entry);
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv->_flagged_entry = _tmp1_;
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_notify ((GObject *) self, "flagged-entry");
#line 1387 "Branch.c"
}


LibraryLastImportSidebarEntry* library_branch_get_last_imported_entry (LibraryBranch* self) {
	LibraryLastImportSidebarEntry* result;
	LibraryLastImportSidebarEntry* _tmp0_ = NULL;
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (LIBRARY_IS_BRANCH (self), NULL);
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_last_imported_entry;
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp0_;
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1402 "Branch.c"
}


static void library_branch_set_last_imported_entry (LibraryBranch* self, LibraryLastImportSidebarEntry* value) {
	LibraryLastImportSidebarEntry* _tmp0_ = NULL;
	LibraryLastImportSidebarEntry* _tmp1_ = NULL;
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = value;
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_last_imported_entry);
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv->_last_imported_entry = _tmp1_;
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_notify ((GObject *) self, "last-imported-entry");
#line 1421 "Branch.c"
}


LibraryImportQueueSidebarEntry* library_branch_get_import_queue_entry (LibraryBranch* self) {
	LibraryImportQueueSidebarEntry* result;
	LibraryImportQueueSidebarEntry* _tmp0_ = NULL;
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (LIBRARY_IS_BRANCH (self), NULL);
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_import_queue_entry;
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp0_;
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1436 "Branch.c"
}


static void library_branch_set_import_queue_entry (LibraryBranch* self, LibraryImportQueueSidebarEntry* value) {
	LibraryImportQueueSidebarEntry* _tmp0_ = NULL;
	LibraryImportQueueSidebarEntry* _tmp1_ = NULL;
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = value;
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_import_queue_entry);
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv->_import_queue_entry = _tmp1_;
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_notify ((GObject *) self, "import-queue-entry");
#line 1455 "Branch.c"
}


LibraryOfflineSidebarEntry* library_branch_get_offline_entry (LibraryBranch* self) {
	LibraryOfflineSidebarEntry* result;
	LibraryOfflineSidebarEntry* _tmp0_ = NULL;
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (LIBRARY_IS_BRANCH (self), NULL);
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_offline_entry;
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp0_;
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1470 "Branch.c"
}


static void library_branch_set_offline_entry (LibraryBranch* self, LibraryOfflineSidebarEntry* value) {
	LibraryOfflineSidebarEntry* _tmp0_ = NULL;
	LibraryOfflineSidebarEntry* _tmp1_ = NULL;
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = value;
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_offline_entry);
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv->_offline_entry = _tmp1_;
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_notify ((GObject *) self, "offline-entry");
#line 1489 "Branch.c"
}


LibraryTrashSidebarEntry* library_branch_get_trash_entry (LibraryBranch* self) {
	LibraryTrashSidebarEntry* result;
	LibraryTrashSidebarEntry* _tmp0_ = NULL;
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (LIBRARY_IS_BRANCH (self), NULL);
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->_trash_entry;
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp0_;
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1504 "Branch.c"
}


static void library_branch_set_trash_entry (LibraryBranch* self, LibraryTrashSidebarEntry* value) {
	LibraryTrashSidebarEntry* _tmp0_ = NULL;
	LibraryTrashSidebarEntry* _tmp1_ = NULL;
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_BRANCH (self));
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = value;
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_trash_entry);
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv->_trash_entry = _tmp1_;
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_notify ((GObject *) self, "trash-entry");
#line 1523 "Branch.c"
}


static void library_branch_class_init (LibraryBranchClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_branch_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_type_class_add_private (klass, sizeof (LibraryBranchPrivate));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_library_branch_get_property;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_library_branch_set_property;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	G_OBJECT_CLASS (klass)->finalize = library_branch_finalize;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), LIBRARY_BRANCH_PHOTOS_ENTRY, g_param_spec_object ("photos-entry", "photos-entry", "photos-entry", LIBRARY_TYPE_PHOTOS_ENTRY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), LIBRARY_BRANCH_FLAGGED_ENTRY, g_param_spec_object ("flagged-entry", "flagged-entry", "flagged-entry", LIBRARY_TYPE_FLAGGED_SIDEBAR_ENTRY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), LIBRARY_BRANCH_LAST_IMPORTED_ENTRY, g_param_spec_object ("last-imported-entry", "last-imported-entry", "last-imported-entry", LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), LIBRARY_BRANCH_IMPORT_QUEUE_ENTRY, g_param_spec_object ("import-queue-entry", "import-queue-entry", "import-queue-entry", LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), LIBRARY_BRANCH_OFFLINE_ENTRY, g_param_spec_object ("offline-entry", "offline-entry", "offline-entry", LIBRARY_TYPE_OFFLINE_SIDEBAR_ENTRY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), LIBRARY_BRANCH_TRASH_ENTRY, g_param_spec_object ("trash-entry", "trash-entry", "trash-entry", LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 1550 "Branch.c"
}


static void library_branch_instance_init (LibraryBranch * self) {
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv = LIBRARY_BRANCH_GET_PRIVATE (self);
#line 1557 "Branch.c"
}


static void library_branch_finalize (GObject* obj) {
	LibraryBranch * self;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBRARY_TYPE_BRANCH, LibraryBranch);
#line 10 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_photos_entry);
#line 11 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_flagged_entry);
#line 12 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_last_imported_entry);
#line 13 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_import_queue_entry);
#line 14 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_offline_entry);
#line 15 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (self->priv->_trash_entry);
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	G_OBJECT_CLASS (library_branch_parent_class)->finalize (obj);
#line 1579 "Branch.c"
}


GType library_branch_get_type (void) {
	static volatile gsize library_branch_type_id__volatile = 0;
	if (g_once_init_enter (&library_branch_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryBranchClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_branch_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryBranch), 0, (GInstanceInitFunc) library_branch_instance_init, NULL };
		GType library_branch_type_id;
		library_branch_type_id = g_type_register_static (SIDEBAR_TYPE_BRANCH, "LibraryBranch", &g_define_type_info, 0);
		g_once_init_leave (&library_branch_type_id__volatile, library_branch_type_id);
	}
	return library_branch_type_id__volatile;
}


static void _vala_library_branch_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	LibraryBranch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LIBRARY_TYPE_BRANCH, LibraryBranch);
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	switch (property_id) {
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_PHOTOS_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		g_value_set_object (value, library_branch_get_photos_entry (self));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_FLAGGED_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		g_value_set_object (value, library_branch_get_flagged_entry (self));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_LAST_IMPORTED_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		g_value_set_object (value, library_branch_get_last_imported_entry (self));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_IMPORT_QUEUE_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		g_value_set_object (value, library_branch_get_import_queue_entry (self));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_OFFLINE_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		g_value_set_object (value, library_branch_get_offline_entry (self));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_TRASH_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		g_value_set_object (value, library_branch_get_trash_entry (self));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 1636 "Branch.c"
		default:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 1642 "Branch.c"
	}
}


static void _vala_library_branch_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	LibraryBranch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LIBRARY_TYPE_BRANCH, LibraryBranch);
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
	switch (property_id) {
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_PHOTOS_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		library_branch_set_photos_entry (self, g_value_get_object (value));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_FLAGGED_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		library_branch_set_flagged_entry (self, g_value_get_object (value));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_LAST_IMPORTED_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		library_branch_set_last_imported_entry (self, g_value_get_object (value));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_IMPORT_QUEUE_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		library_branch_set_import_queue_entry (self, g_value_get_object (value));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_OFFLINE_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		library_branch_set_offline_entry (self, g_value_get_object (value));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_BRANCH_TRASH_ENTRY:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		library_branch_set_trash_entry (self, g_value_get_object (value));
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 1688 "Branch.c"
		default:
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 1694 "Branch.c"
	}
}


LibraryPhotosEntry* library_photos_entry_construct (GType object_type) {
	LibraryPhotosEntry * self = NULL;
#line 93 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = (LibraryPhotosEntry*) sidebar_simple_page_entry_construct (object_type);
#line 93 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return self;
#line 1705 "Branch.c"
}


LibraryPhotosEntry* library_photos_entry_new (void) {
#line 93 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return library_photos_entry_construct (LIBRARY_TYPE_PHOTOS_ENTRY);
#line 1712 "Branch.c"
}


static gchar* library_photos_entry_real_get_sidebar_name (SidebarSimplePageEntry* base) {
	LibraryPhotosEntry * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 96 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntry);
#line 97 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = _ ("Photos");
#line 97 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 97 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp1_;
#line 97 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1731 "Branch.c"
}


static gchar* library_photos_entry_real_get_sidebar_icon (SidebarSimplePageEntry* base) {
	LibraryPhotosEntry * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 100 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntry);
#line 101 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = g_strdup (RESOURCES_ICON_PHOTOS);
#line 101 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp0_;
#line 101 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1747 "Branch.c"
}


static Page* library_photos_entry_real_create_page (SidebarSimplePageEntry* base) {
	LibraryPhotosEntry * self;
	Page* result = NULL;
	LibraryMainPage* _tmp0_ = NULL;
#line 104 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntry);
#line 105 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = library_main_page_new (NULL, NULL);
#line 105 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_ref_sink (_tmp0_);
#line 105 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PAGE, Page);
#line 105 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1765 "Branch.c"
}


static void library_photos_entry_class_init (LibraryPhotosEntryClass * klass) {
#line 91 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_photos_entry_parent_class = g_type_class_peek_parent (klass);
#line 91 "/home/jens/Source/shotwell/src/library/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_name = library_photos_entry_real_get_sidebar_name;
#line 91 "/home/jens/Source/shotwell/src/library/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_icon = library_photos_entry_real_get_sidebar_icon;
#line 91 "/home/jens/Source/shotwell/src/library/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->create_page = library_photos_entry_real_create_page;
#line 1778 "Branch.c"
}


static void library_photos_entry_instance_init (LibraryPhotosEntry * self) {
}


GType library_photos_entry_get_type (void) {
	static volatile gsize library_photos_entry_type_id__volatile = 0;
	if (g_once_init_enter (&library_photos_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryPhotosEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_photos_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryPhotosEntry), 0, (GInstanceInitFunc) library_photos_entry_instance_init, NULL };
		GType library_photos_entry_type_id;
		library_photos_entry_type_id = g_type_register_static (SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, "LibraryPhotosEntry", &g_define_type_info, 0);
		g_once_init_leave (&library_photos_entry_type_id__volatile, library_photos_entry_type_id);
	}
	return library_photos_entry_type_id__volatile;
}


LibraryHideablePageEntry* library_hideable_page_entry_construct (GType object_type) {
	LibraryHideablePageEntry * self = NULL;
#line 125 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = (LibraryHideablePageEntry*) sidebar_simple_page_entry_construct (object_type);
#line 125 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return self;
#line 1804 "Branch.c"
}


gboolean library_hideable_page_entry_get_visible (LibraryHideablePageEntry* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 115 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_val_if_fail (LIBRARY_IS_HIDEABLE_PAGE_ENTRY (self), FALSE);
#line 115 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = self->priv->show_entry;
#line 115 "/home/jens/Source/shotwell/src/library/Branch.vala"
	result = _tmp0_;
#line 115 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return result;
#line 1819 "Branch.c"
}


void library_hideable_page_entry_set_visible (LibraryHideablePageEntry* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 116 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_return_if_fail (LIBRARY_IS_HIDEABLE_PAGE_ENTRY (self));
#line 117 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = value;
#line 117 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = self->priv->show_entry;
#line 117 "/home/jens/Source/shotwell/src/library/Branch.vala"
	if (_tmp0_ == _tmp1_) {
#line 118 "/home/jens/Source/shotwell/src/library/Branch.vala"
		return;
#line 1838 "Branch.c"
	}
#line 120 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp2_ = value;
#line 120 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv->show_entry = _tmp2_;
#line 121 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp3_ = value;
#line 121 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_signal_emit_by_name (self, "visibility-changed", _tmp3_);
#line 116 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_notify ((GObject *) self, "visible");
#line 1850 "Branch.c"
}


static void library_hideable_page_entry_class_init (LibraryHideablePageEntryClass * klass) {
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_hideable_page_entry_parent_class = g_type_class_peek_parent (klass);
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_type_class_add_private (klass, sizeof (LibraryHideablePageEntryPrivate));
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_library_hideable_page_entry_get_property;
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_library_hideable_page_entry_set_property;
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	G_OBJECT_CLASS (klass)->finalize = library_hideable_page_entry_finalize;
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), LIBRARY_HIDEABLE_PAGE_ENTRY_VISIBLE, g_param_spec_boolean ("visible", "visible", "visible", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	g_signal_new ("visibility_changed", LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
#line 1869 "Branch.c"
}


static void library_hideable_page_entry_instance_init (LibraryHideablePageEntry * self) {
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv = LIBRARY_HIDEABLE_PAGE_ENTRY_GET_PRIVATE (self);
#line 113 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self->priv->show_entry = FALSE;
#line 1878 "Branch.c"
}


static void library_hideable_page_entry_finalize (GObject* obj) {
	LibraryHideablePageEntry * self;
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry);
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	G_OBJECT_CLASS (library_hideable_page_entry_parent_class)->finalize (obj);
#line 1888 "Branch.c"
}


GType library_hideable_page_entry_get_type (void) {
	static volatile gsize library_hideable_page_entry_type_id__volatile = 0;
	if (g_once_init_enter (&library_hideable_page_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryHideablePageEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_hideable_page_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryHideablePageEntry), 0, (GInstanceInitFunc) library_hideable_page_entry_instance_init, NULL };
		GType library_hideable_page_entry_type_id;
		library_hideable_page_entry_type_id = g_type_register_static (SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, "LibraryHideablePageEntry", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&library_hideable_page_entry_type_id__volatile, library_hideable_page_entry_type_id);
	}
	return library_hideable_page_entry_type_id__volatile;
}


static void _vala_library_hideable_page_entry_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	LibraryHideablePageEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry);
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	switch (property_id) {
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_HIDEABLE_PAGE_ENTRY_VISIBLE:
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		g_value_set_boolean (value, library_hideable_page_entry_get_visible (self));
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 1915 "Branch.c"
		default:
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 1921 "Branch.c"
	}
}


static void _vala_library_hideable_page_entry_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	LibraryHideablePageEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry);
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
	switch (property_id) {
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		case LIBRARY_HIDEABLE_PAGE_ENTRY_VISIBLE:
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		library_hideable_page_entry_set_visible (self, g_value_get_boolean (value));
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 1937 "Branch.c"
		default:
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 109 "/home/jens/Source/shotwell/src/library/Branch.vala"
		break;
#line 1943 "Branch.c"
	}
}


LibraryMainPage* library_main_page_construct (GType object_type, ProgressMonitor monitor, void* monitor_target) {
	LibraryMainPage * self = NULL;
#line 133 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = (LibraryMainPage*) collection_page_construct (object_type, LIBRARY_MAIN_PAGE_NAME);
#line 1952 "Branch.c"
	{
		GeeIterator* _sources_it = NULL;
		MediaCollectionRegistry* _tmp0_ = NULL;
		MediaCollectionRegistry* _tmp1_ = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeCollection* _tmp3_ = NULL;
		GeeIterator* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp0_ = media_collection_registry_get_instance ();
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp1_ = _tmp0_;
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp2_ = media_collection_registry_get_all (_tmp1_);
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp3_ = _tmp2_;
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_tmp5_ = _tmp4_;
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_g_object_unref0 (_tmp3_);
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_media_collection_registry_unref0 (_tmp1_);
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_sources_it = _tmp5_;
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		while (TRUE) {
#line 1981 "Branch.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			MediaSourceCollection* sources = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			ViewCollection* _tmp10_ = NULL;
			ViewCollection* _tmp11_ = NULL;
			MediaSourceCollection* _tmp12_ = NULL;
			CollectionViewManager* _tmp13_ = NULL;
			CollectionViewManager* _tmp14_ = NULL;
			ProgressMonitor _tmp15_ = NULL;
			void* _tmp15__target = NULL;
			ViewCollectionMonitor* _tmp16_ = NULL;
			ViewCollectionMonitor* _tmp17_ = NULL;
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp6_ = _sources_it;
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
			if (!_tmp7_) {
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
				break;
#line 2004 "Branch.c"
			}
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp8_ = _sources_it;
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
			sources = (MediaSourceCollection*) _tmp9_;
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp10_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp11_ = _tmp10_;
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp12_ = sources;
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp13_ = collection_view_manager_new (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_COLLECTION_PAGE, CollectionPage));
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp14_ = _tmp13_;
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp15_ = monitor;
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp15__target = monitor_target;
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp16_ = view_collection_monitor_source_collection (_tmp11_, G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_SOURCE_COLLECTION, SourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_VIEW_MANAGER, ViewManager), NULL, NULL, _tmp15_, _tmp15__target);
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_tmp17_ = _tmp16_;
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_view_collection_monitor_unref0 (_tmp17_);
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_view_manager_unref0 (_tmp14_);
#line 136 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_data_collection_unref0 (_tmp11_);
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
			_data_collection_unref0 (sources);
#line 2038 "Branch.c"
		}
#line 135 "/home/jens/Source/shotwell/src/library/Branch.vala"
		_g_object_unref0 (_sources_it);
#line 2042 "Branch.c"
	}
#line 132 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return self;
#line 2046 "Branch.c"
}


LibraryMainPage* library_main_page_new (ProgressMonitor monitor, void* monitor_target) {
#line 132 "/home/jens/Source/shotwell/src/library/Branch.vala"
	return library_main_page_construct (LIBRARY_TYPE_MAIN_PAGE, monitor, monitor_target);
#line 2053 "Branch.c"
}


static void library_main_page_real_get_config_photos_sort (MediaPage* base, gboolean* sort_order, gint* sort_by) {
	LibraryMainPage * self;
	gboolean _vala_sort_order = FALSE;
	gint _vala_sort_by = 0;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gint _tmp3_ = 0;
#line 139 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_MAIN_PAGE, LibraryMainPage);
#line 140 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = config_facade_get_instance ();
#line 140 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = _tmp0_;
#line 140 "/home/jens/Source/shotwell/src/library/Branch.vala"
	configuration_facade_get_library_photos_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), &_tmp2_, &_tmp3_);
#line 140 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_vala_sort_order = _tmp2_;
#line 140 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_vala_sort_by = _tmp3_;
#line 140 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp1_);
#line 139 "/home/jens/Source/shotwell/src/library/Branch.vala"
	if (sort_order) {
#line 139 "/home/jens/Source/shotwell/src/library/Branch.vala"
		*sort_order = _vala_sort_order;
#line 2083 "Branch.c"
	}
#line 139 "/home/jens/Source/shotwell/src/library/Branch.vala"
	if (sort_by) {
#line 139 "/home/jens/Source/shotwell/src/library/Branch.vala"
		*sort_by = _vala_sort_by;
#line 2089 "Branch.c"
	}
}


static void library_main_page_real_set_config_photos_sort (MediaPage* base, gboolean sort_order, gint sort_by) {
	LibraryMainPage * self;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gint _tmp3_ = 0;
#line 143 "/home/jens/Source/shotwell/src/library/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_MAIN_PAGE, LibraryMainPage);
#line 144 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp0_ = config_facade_get_instance ();
#line 144 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp1_ = _tmp0_;
#line 144 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp2_ = sort_order;
#line 144 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_tmp3_ = sort_by;
#line 144 "/home/jens/Source/shotwell/src/library/Branch.vala"
	configuration_facade_set_library_photos_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_);
#line 144 "/home/jens/Source/shotwell/src/library/Branch.vala"
	_g_object_unref0 (_tmp1_);
#line 2114 "Branch.c"
}


static void library_main_page_class_init (LibraryMainPageClass * klass) {
#line 129 "/home/jens/Source/shotwell/src/library/Branch.vala"
	library_main_page_parent_class = g_type_class_peek_parent (klass);
#line 129 "/home/jens/Source/shotwell/src/library/Branch.vala"
	((MediaPageClass *) klass)->get_config_photos_sort = library_main_page_real_get_config_photos_sort;
#line 129 "/home/jens/Source/shotwell/src/library/Branch.vala"
	((MediaPageClass *) klass)->set_config_photos_sort = library_main_page_real_set_config_photos_sort;
#line 2125 "Branch.c"
}


static void library_main_page_instance_init (LibraryMainPage * self) {
}


GType library_main_page_get_type (void) {
	static volatile gsize library_main_page_type_id__volatile = 0;
	if (g_once_init_enter (&library_main_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryMainPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_main_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryMainPage), 0, (GInstanceInitFunc) library_main_page_instance_init, NULL };
		GType library_main_page_type_id;
		library_main_page_type_id = g_type_register_static (TYPE_COLLECTION_PAGE, "LibraryMainPage", &g_define_type_info, 0);
		g_once_init_leave (&library_main_page_type_id__volatile, library_main_page_type_id);
	}
	return library_main_page_type_id__volatile;
}



